(() => {
  const delay = (ms) => new Promise((resolve) => setTimeout(resolve, ms));

  const handleDynamicJobDetails = async () => {
    const maxWaitTime = 60000; // Maximum wait time (ms) for AJAX content to load
    const pollInterval = 100; // Interval (ms) to check for content
    let elapsedTime = 0;

    while (elapsedTime < maxWaitTime) {
      // Check if "Invites sent" text exists
      const invitesSentElement = [...document.querySelectorAll("span")].find(
        (el) => el.textContent.trim() === "Invites sent:"
      );

      if (invitesSentElement) {
        return true; // Job details loaded
      }

      await new Promise((resolve) => setTimeout(resolve, pollInterval));
      elapsedTime += pollInterval;
    }
    return false; // Timeout reached
  };

  const analyzeJobDetails = async () => {
    const messages = [];

    // Step 1: Check for preferred qualifications
    const qualifications = document.querySelector("ul.qualification-items");
    if (qualifications && qualifications.querySelectorAll("li").length > 0) {
      messages.push("Please take note of the preferred qualifications before applying to the job.");
    }

    // Step 2: Check if it's a new client's first job
    const hireRateOneOpenJob = document.body.textContent.match(/\b0% hire rate, 1 open job\b/);
    if (hireRateOneOpenJob) {
      const jobsPostedElement = [...document.querySelectorAll("strong")].find((el) =>
        el.textContent.match(/\b(\d+) job posted\b/)
      );

      if (jobsPostedElement) {
        const jobsPosted = parseInt(jobsPostedElement.textContent.match(/\b(\d+) job posted\b/)[1]);

        if (jobsPosted === 1) {
          messages.push("The job is posted by a new client. It's their first job.");
        }
      } else {
        messages.push("The job is posted by a new client. It's their first job.");
      }
    }

    // Step 3: Check if it's a new client with multiple jobs posted
    const hireRateMultipleOpenJobs = document.body.textContent.match(/\b0% hire rate, (\d+) open jobs\b/);
    if (hireRateMultipleOpenJobs) {
      const openJobsCount = parseInt(hireRateMultipleOpenJobs[1]);

      if (openJobsCount > 1) {
        const jobsPostedElement = [...document.querySelectorAll("strong")].find((el) =>
          el.textContent.match(/\b(\d+) jobs posted\b/)
        );

        if (jobsPostedElement) {
          messages.push(
            "The job is posted by a new client, but it's not their first job. Be careful. It could be a fake job."
          );
        } else {
          messages.push(
            "The job is posted by a new client, but it's not their first job. Be careful. It could be a fake job."
          );
        }
      }
    }

    // Step 4: Check if the client has viewed the job after posting
    if (!document.body.textContent.includes("Last viewed by client:")) {
      messages.push("The client hasn't viewed the job after posting.");
    }

    // Step 5: Check the hiring rate for existing clients
    const existingClientMatch = document.body.textContent.match(/(\d+)% hire rate/);
    if (existingClientMatch && parseInt(existingClientMatch[1]) < 70) {
      messages.push("The client hiring rate is less than 70%.");
    }

    // Step 6: Check invitations sent
    const invitesSentSpan = [...document.querySelectorAll("span")].find(
      (el) => el.textContent.trim() === "Invites sent:"
    );
    if (invitesSentSpan) {
      const nextDiv = invitesSentSpan.nextElementSibling;
      if (nextDiv && nextDiv.textContent.trim() === "1") {
        messages.push("The client has only invited 1 person. They will most likely go with them.");
      }
    }

    // Step 7: Analyze freelancer hiring history
    await delay(500);
    const freelancerSpans = document.querySelectorAll('span[data-test="FreelancerLink"]');
    const freelancerNames = [...freelancerSpans].map((span) => span.textContent.trim());
    const duplicates = freelancerNames.filter((name, index, self) => self.indexOf(name) !== index);

    if (duplicates.length > 0) {
      messages.push(
        "The client has hired the same freelancer multiple times in the past. Make sure the freelancer is not related to the same job niche you are applying to. The client might go with a familiar freelancer."
      );
    }

    // Step 8: Check if a span with class "title" contains "Hires:"
    const hiresSpan = [...document.querySelectorAll("span.title")].find(
      (el) => el.textContent.trim() === "Hires:"
    );

    if (hiresSpan) {
      messages.push("The client has already hired someone.");
    }

    // Display messages
    if (messages.length > 0) {
      alert(messages.join("\n"));
    } else {
      alert("The job is good to go!");
    }
  };

  const handleUrlChange = async () => {
    // Handle AJAX-loaded jobs for both URL patterns
    if (
      location.href.includes("/nx/search/jobs/details/~") ||
      location.href.includes("/nx/find-work/best-matches/details/~") ||
      location.href.includes("/nx/find-work/most-recent/details/~") ||
      location.href.includes("/nx/find-work/saved-jobs/details/~")
    ) {
      if (await handleDynamicJobDetails()) {
        analyzeJobDetails();
      }
    }
    // Handle static job detail pages
    else if (location.href.match(/\/jobs\/(~|[a-zA-Z0-9-_]+~)/)) {
      analyzeJobDetails();
    }
  };

  // Handle URL changes dynamically (AJAX loading)
  let lastUrl = location.href;
  const observer = new MutationObserver(() => {
    if (location.href !== lastUrl) {
      lastUrl = location.href;
      handleUrlChange();
    }
  });
  observer.observe(document.body, { childList: true, subtree: true });

  // Initial execution
  handleUrlChange();
})();
